pub(crate) enum CsFold {
Single(FieldInfo),
Combine(Span, Box<Expr>, Box<Expr>),
Fieldless,
}Expand description
The function passed to cs_fold is called repeatedly with a value of this
type. It describes one part of the code generation. The result is always an
expression.
Variants
Single(FieldInfo)
The basic case: a field expression for one or more selflike args. E.g.
for PartialEq::eq this is something like self.x == other.x.
Combine(Span, Box<Expr>, Box<Expr>)
The combination of two field expressions. E.g. for PartialEq::eq this
is something like <field1 equality> && <field2 equality>.
Fieldless